@@ -1,8 +1,8 @@
 package re::engine::RE2;
-use 5.012;
+use 5.020;
 
 BEGIN {
-  $re::engine::RE2::VERSION = "0.13";
+  $re::engine::RE2::VERSION = "0.16";
 }
 
 use XSLoader ();
@@ -98,6 +98,25 @@ Example:
     is $min, 'a';
     is $max, 'c';'
 
+=item * C<named_captures()>
+
+Returns a hash of the name captures and index.
+
+Example:
+
+    my $named_captures = qr/(?P<a>\w+) (?P<d>\w+)/->named_captures;
+    is $named_captures->{a}, 1;
+    is $named_captures->{d}, 2;
+
+=item * C<number_of_capture_groups()>
+
+Return number of capture groups
+
+Example:
+
+    my $captures = qr/(Hello), (world)/->number_of_capture_groups;
+    is $captures, 2;
+
 =back
 
 =head1 PRAGMA OPTIONS
@@ -225,8 +244,7 @@ C<\n?\z> when you mean Perl's C<$>.
 
 =back
 
-Please report bugs via RT in the normal way. (Or a patch at
-L<https://github.com/dgl/re-engine-RE2> would be most welcome.)
+Please report bugs or provide patches at <https://github.com/dgl/re-engine-RE2>.
 
 =head1 AUTHORS
 
